@@ -13,11 +13,10 @@ def setup(context):
         try:
             if not os.path.isdir(path):
                 os.mkdir(path)
-            logger.info("No default sms path for smsmock is specified. Using %s" % path)
+            logger.info(f"No default sms path for smsmock is specified. Using {path}")
         except OSError:
             logger.error(
-                "No default sms path for smsmock is specified. Unable to create %s"
-                % path
+                f"No default sms path for smsmock is specified. Unable to create {path}"
             )
             exit(1)
         context.sms_path = path
