@@ -38,12 +38,11 @@ def after_scenario(context, scenario):
         and context.screenshots_dir
         and hasattr(context, "browser")
     ):
-
         filename = (
             scenario.feature.name
-            + u"-"
+            + "-"
             + scenario.name
-            + u"-"
+            + "-"
             + time.strftime("%Y-%m-%d-%H%M%S", time.gmtime(time.time()))
         )
         filename = os.path.join(context.screenshots_dir, filename)
