@@ -1,18 +1,19 @@
-from behave import step
+from behave import then, when
 from selenium.common.exceptions import NoAlertPresentException
+
 from behaving.personas.persona import persona_vars
 from behaving.web.steps.basic import _retry
 
 
-@step(u"I should see an alert")
+@then("I should see an alert")
 def alert_is_present(context):
     try:
-        assert context.browser.get_alert(), u"Alert not found"
+        assert context.browser.get_alert(), "Alert not found"
     except NoAlertPresentException:
-        assert False, u"Alert not found"
+        assert False, "Alert not found"
 
 
-@step(u"I should see an alert within {timeout:d} seconds")
+@then("I should see an alert within {timeout:d} seconds")
 def alert_is_present_timeout(context, timeout):
     def check():
         try:
@@ -21,19 +22,19 @@ def alert_is_present_timeout(context, timeout):
         except NoAlertPresentException:
             return False
 
-    assert _retry(check, timeout), u"Alert not found"
+    assert _retry(check, timeout), "Alert not found"
 
 
-@step(u'I should see an alert containing "{text}"')
+@then('I should see an alert containing "{text}"')
 def alert_contains_text(context, text):
     try:
         alert = context.browser.get_alert()
-        assert text in alert.text, u"Text not found"
+        assert text in alert.text, f"Text {text} not found in alerts"
     except NoAlertPresentException:
-        assert False, u"Alert not found"
+        assert False, "Alert not found"
 
 
-@step(u'I should see an alert containing "{text}" within {timeout:d} seconds')
+@then('I should see an alert containing "{text}" within {timeout:d} seconds')
 def alert_contains_text_timeout(context, text, timeout):
     def check():
         try:
@@ -42,26 +43,26 @@ def alert_contains_text_timeout(context, text, timeout):
         except NoAlertPresentException:
             return False
 
-    assert _retry(check, timeout), u"Alert not found"
+    assert _retry(check, timeout), f"Alert containing {text} not found"
 
 
-@step(u'I enter "{text}" to the alert')
+@when('I enter "{text}" to the alert')
 @persona_vars
 def set_alert_text(context, text):
     alert = context.browser.driver.switch_to.alert
-    assert alert, u"Alert not found"
+    assert alert, "Alert not found"
     alert.send_keys(text)
 
 
-@step(u"I accept the alert")
+@when("I accept the alert")
 def accept_alert(context):
     alert = context.browser.driver.switch_to.alert
-    assert alert, u"Alert not found"
+    assert alert, "Alert not found"
     alert.accept()
 
 
-@step(u"I dismiss the alert")
+@when("I dismiss the alert")
 def dimiss_alert(context):
     alert = context.browser.driver.switch_to.alert
-    assert alert, u"Alert not found"
+    assert alert, "Alert not found"
     alert.dismiss()
