@@ -65,6 +65,7 @@ def i_type_to(context, name, value):
 @when('I choose "{value}" from "{name}"')
 @persona_vars
 def i_choose_in_radio(context, name, value):
+    find_by_name_or_id(context, name)
     context.browser.choose(name, value)
 
 
@@ -91,6 +92,20 @@ def i_toggle(context, name):
         el.check()
 
 
+@then('the field "{name}" should be checked')
+def is_checked(context, name):
+    el = find_by_name_or_id(context, name)
+    assert el.checked, f'The field with name or id "{name}" was expected to be checked.'
+
+
+@then('the field "{name}" should be unchecked')
+def is_not_checked(context, name):
+    el = find_by_name_or_id(context, name)
+    assert (
+        not el.checked
+    ), f'The field with name or id "{name}" was expected to be unchecked.'
+
+
 @when('I select "{value}" from "{name}"')
 @persona_vars
 def i_select(context, value, name):
@@ -144,7 +159,6 @@ def i_press(context, name):
 @when('I press the element with xpath "{xpath}"')
 @persona_vars
 def i_press_xpath(context, xpath):
-
     button = context.browser.find_by_xpath(xpath)
     assert button, f"Element with xpath {xpath} not found"
     button.first.click()
@@ -181,17 +195,26 @@ def set_html_content_to_element_with_class(context, klass, contents):
 
 
 @then('field "{name}" should have the value "{value}"')
-@then('field "{name}" should have the value "{value}" within {timeout:d} seconds')
 @persona_vars
 def field_has_value_within_timeout(context, name, value, timeout=None):
-    el = context.browser.find_by_xpath(
-        ("//*[@id='%(name)s']|" "//*[@name='%(name)s']") % {"name": name},
-        wait_time=timeout,
-    )
-    assert el, f"Element with name or id {name} not found"
+    el = find_by_name_or_id(context, name)
     assert (
-        el.first.value == value
-    ), f"Values for element {name} do not match, expected {value} but got {el.first.value}"
+        el.value == value
+    ), f'Values for element {name} do not match, expected "{value}" but got "{el.value}"'
+
+
+@then('the selection "{name}" should have the option "{values}" selected')
+@then('the selection "{name}" should have the options "{values}" selected')
+@persona_vars
+def select_has_selected_within_timeout(context, name, values, timeout=None):
+    el = find_by_name_or_id(context, name)
+    assert el.tag_name == "select", f"Element {name} is not a <select/>"
+    values = set([v.strip() for v in values.split(",")])
+    options = el.find_by_tag("option")
+    selected = set([o.value for o in options if o.selected])
+    assert (
+        selected == values
+    ), f'Values for element {name} do not match, expected "{values}" but got "{selected}"'
 
 
 @then('field "{name}" should be empty')
