@@ -3,7 +3,7 @@ from selenium.common.exceptions import NoSuchElementException
 from selenium.webdriver.common.by import By
 
 
-@when(u'I switch to frame with css "{css}"')
+@when('I switch to frame with css "{css}"')
 def switch_to_frame(context, css):
     driver = context.browser.driver
     try:
@@ -13,6 +13,6 @@ def switch_to_frame(context, css):
     driver.switch_to.frame(frame)
 
 
-@when(u"I switch back to the main page")
+@when("I switch back to the main page")
 def switch_to_main_page(context):
     context.browser.driver.switch_to.default_content()
